@@ -1,5 +1,5 @@
 package QBit::WebInterface::Routing::Routes;
-$QBit::WebInterface::Routing::Routes::VERSION = '0.008';
+$QBit::WebInterface::Routing::Routes::VERSION = '0.009';
 use qbit;
 
 use base qw(QBit::Class);
@@ -573,7 +573,7 @@ sub url_for {
         }
     }
 
-    throw Exception::Routes gettex('Route with name "%s" not found', $name) unless $route;
+    throw Exception::Routes gettext('Route with name "%s" not found', $name) unless $route;
 
     my $url;
     if (@{$route->{'params'}}) {
